@@ -2,15 +2,10 @@ import os
 import json
 import click
 import subprocess
-from dotenv import load_dotenv
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery
-from jnius import autoclass
-
-
-load_dotenv()
 
 OPERATOR_ID = AccountId.fromString(os.getenv("OPERATOR_ID"))
-OPERATOR_KEY = PrivateKey.fromString(os.getenv("OPERATOR_KEY"))
+OPERATOR_PRIVATE_KEY = PrivateKey.fromString(os.getenv("OPERATOR_PRIVATE_KEY"))
 
 class Network3Medusa():
     def __init__(self, command):
@@ -26,9 +21,10 @@ class Network3Medusa():
 
     def add_file_to_hedera(self, raw_json):
         client = Client.forTestnet()
-        client.setOperator(OPERATOR_ID, OPERATOR_KEY)
+        client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        resp = tran.setKeys(OPERATOR_KEY.getPublicKey()).setContents("test").setMaxTransactionFee(Hbar(2)).execute(client)
+        fileContents = raw_json
+        resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(client)
         print("nodeId: ",  resp.nodeId.toString())
         receipt = resp.getReceipt(client)
         fileId = receipt.fileId
